import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IdentitystoreClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IdentitystoreClient";
import { GetGroupMembershipIdRequest, GetGroupMembershipIdResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetGroupMembershipIdCommand}.
 */
export interface GetGroupMembershipIdCommandInput extends GetGroupMembershipIdRequest {
}
/**
 * @public
 *
 * The output of {@link GetGroupMembershipIdCommand}.
 */
export interface GetGroupMembershipIdCommandOutput extends GetGroupMembershipIdResponse, __MetadataBearer {
}
declare const GetGroupMembershipIdCommand_base: {
    new (input: GetGroupMembershipIdCommandInput): import("@smithy/smithy-client").CommandImpl<GetGroupMembershipIdCommandInput, GetGroupMembershipIdCommandOutput, IdentitystoreClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetGroupMembershipIdCommandInput): import("@smithy/smithy-client").CommandImpl<GetGroupMembershipIdCommandInput, GetGroupMembershipIdCommandOutput, IdentitystoreClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Retrieves the <code>MembershipId</code> in an identity store.</p>
 *          <note>
 *             <p>If you have administrator access to a member account, you can use this API from the member account.
 *          Read about <a href="https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_accounts_access.html">member accounts</a> in the
 *          <i>Organizations User Guide</i>. </p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IdentitystoreClient, GetGroupMembershipIdCommand } from "@aws-sdk/client-identitystore"; // ES Modules import
 * // const { IdentitystoreClient, GetGroupMembershipIdCommand } = require("@aws-sdk/client-identitystore"); // CommonJS import
 * const client = new IdentitystoreClient(config);
 * const input = { // GetGroupMembershipIdRequest
 *   IdentityStoreId: "STRING_VALUE", // required
 *   GroupId: "STRING_VALUE", // required
 *   MemberId: { // MemberId Union: only one key present
 *     UserId: "STRING_VALUE",
 *   },
 * };
 * const command = new GetGroupMembershipIdCommand(input);
 * const response = await client.send(command);
 * // { // GetGroupMembershipIdResponse
 * //   MembershipId: "STRING_VALUE", // required
 * //   IdentityStoreId: "STRING_VALUE", // required
 * // };
 *
 * ```
 *
 * @param GetGroupMembershipIdCommandInput - {@link GetGroupMembershipIdCommandInput}
 * @returns {@link GetGroupMembershipIdCommandOutput}
 * @see {@link GetGroupMembershipIdCommandInput} for command's `input` shape.
 * @see {@link GetGroupMembershipIdCommandOutput} for command's `response` shape.
 * @see {@link IdentitystoreClientResolvedConfig | config} for IdentitystoreClient's `config` shape.
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception or failure with an internal server.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API operations.</p>
 *
 * @throws {@link IdentitystoreServiceException}
 * <p>Base exception class for all service exceptions from Identitystore service.</p>
 *
 * @public
 */
export declare class GetGroupMembershipIdCommand extends GetGroupMembershipIdCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetGroupMembershipIdRequest;
            output: GetGroupMembershipIdResponse;
        };
        sdk: {
            input: GetGroupMembershipIdCommandInput;
            output: GetGroupMembershipIdCommandOutput;
        };
    };
}
