import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { GetApplicationAssignmentConfigurationRequest, GetApplicationAssignmentConfigurationResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetApplicationAssignmentConfigurationCommand}.
 */
export interface GetApplicationAssignmentConfigurationCommandInput extends GetApplicationAssignmentConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link GetApplicationAssignmentConfigurationCommand}.
 */
export interface GetApplicationAssignmentConfigurationCommandOutput extends GetApplicationAssignmentConfigurationResponse, __MetadataBearer {
}
declare const GetApplicationAssignmentConfigurationCommand_base: {
    new (input: GetApplicationAssignmentConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<GetApplicationAssignmentConfigurationCommandInput, GetApplicationAssignmentConfigurationCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetApplicationAssignmentConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<GetApplicationAssignmentConfigurationCommandInput, GetApplicationAssignmentConfigurationCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Retrieves the configuration of <a>PutApplicationAssignmentConfiguration</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, GetApplicationAssignmentConfigurationCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, GetApplicationAssignmentConfigurationCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // GetApplicationAssignmentConfigurationRequest
 *   ApplicationArn: "STRING_VALUE", // required
 * };
 * const command = new GetApplicationAssignmentConfigurationCommand(input);
 * const response = await client.send(command);
 * // { // GetApplicationAssignmentConfigurationResponse
 * //   AssignmentRequired: true || false, // required
 * // };
 *
 * ```
 *
 * @param GetApplicationAssignmentConfigurationCommandInput - {@link GetApplicationAssignmentConfigurationCommandInput}
 * @returns {@link GetApplicationAssignmentConfigurationCommandOutput}
 * @see {@link GetApplicationAssignmentConfigurationCommandInput} for command's `input` shape.
 * @see {@link GetApplicationAssignmentConfigurationCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class GetApplicationAssignmentConfigurationCommand extends GetApplicationAssignmentConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetApplicationAssignmentConfigurationRequest;
            output: GetApplicationAssignmentConfigurationResponse;
        };
        sdk: {
            input: GetApplicationAssignmentConfigurationCommandInput;
            output: GetApplicationAssignmentConfigurationCommandOutput;
        };
    };
}
