import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { DocumentType as __DocumentType } from "@smithy/types";
import { SSOAdminServiceException as __BaseException } from "./SSOAdminServiceException";
export interface AccessControlAttributeValue {
  Source: string[] | undefined;
}
export interface AccessControlAttribute {
  Key: string | undefined;
  Value: AccessControlAttributeValue | undefined;
}
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare const PrincipalType: {
  readonly GROUP: "GROUP";
  readonly USER: "USER";
};
export type PrincipalType = (typeof PrincipalType)[keyof typeof PrincipalType];
export interface AccountAssignment {
  AccountId?: string | undefined;
  PermissionSetArn?: string | undefined;
  PrincipalType?: PrincipalType | undefined;
  PrincipalId?: string | undefined;
}
export interface AccountAssignmentForPrincipal {
  AccountId?: string | undefined;
  PermissionSetArn?: string | undefined;
  PrincipalId?: string | undefined;
  PrincipalType?: PrincipalType | undefined;
}
export declare const StatusValues: {
  readonly FAILED: "FAILED";
  readonly IN_PROGRESS: "IN_PROGRESS";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type StatusValues = (typeof StatusValues)[keyof typeof StatusValues];
export declare const TargetType: {
  readonly AWS_ACCOUNT: "AWS_ACCOUNT";
};
export type TargetType = (typeof TargetType)[keyof typeof TargetType];
export interface AccountAssignmentOperationStatus {
  Status?: StatusValues | undefined;
  RequestId?: string | undefined;
  FailureReason?: string | undefined;
  TargetId?: string | undefined;
  TargetType?: TargetType | undefined;
  PermissionSetArn?: string | undefined;
  PrincipalType?: PrincipalType | undefined;
  PrincipalId?: string | undefined;
  CreatedDate?: Date | undefined;
}
export interface AccountAssignmentOperationStatusMetadata {
  Status?: StatusValues | undefined;
  RequestId?: string | undefined;
  CreatedDate?: Date | undefined;
}
export declare const SignInOrigin: {
  readonly APPLICATION: "APPLICATION";
  readonly IDENTITY_CENTER: "IDENTITY_CENTER";
};
export type SignInOrigin = (typeof SignInOrigin)[keyof typeof SignInOrigin];
export interface SignInOptions {
  Origin: SignInOrigin | undefined;
  ApplicationUrl?: string | undefined;
}
export declare const ApplicationVisibility: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type ApplicationVisibility =
  (typeof ApplicationVisibility)[keyof typeof ApplicationVisibility];
export interface PortalOptions {
  SignInOptions?: SignInOptions | undefined;
  Visibility?: ApplicationVisibility | undefined;
}
export declare const ApplicationStatus: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type ApplicationStatus =
  (typeof ApplicationStatus)[keyof typeof ApplicationStatus];
export interface Application {
  ApplicationArn?: string | undefined;
  ApplicationProviderArn?: string | undefined;
  Name?: string | undefined;
  ApplicationAccount?: string | undefined;
  InstanceArn?: string | undefined;
  Status?: ApplicationStatus | undefined;
  PortalOptions?: PortalOptions | undefined;
  Description?: string | undefined;
  CreatedDate?: Date | undefined;
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export interface DeleteApplicationAccessScopeRequest {
  ApplicationArn: string | undefined;
  Scope: string | undefined;
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface GetApplicationAccessScopeRequest {
  ApplicationArn: string | undefined;
  Scope: string | undefined;
}
export interface GetApplicationAccessScopeResponse {
  Scope: string | undefined;
  AuthorizedTargets?: string[] | undefined;
}
export interface ListApplicationAccessScopesRequest {
  ApplicationArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ScopeDetails {
  Scope: string | undefined;
  AuthorizedTargets?: string[] | undefined;
}
export interface ListApplicationAccessScopesResponse {
  Scopes: ScopeDetails[] | undefined;
  NextToken?: string | undefined;
}
export interface PutApplicationAccessScopeRequest {
  Scope: string | undefined;
  AuthorizedTargets?: string[] | undefined;
  ApplicationArn: string | undefined;
}
export interface ApplicationAssignment {
  ApplicationArn: string | undefined;
  PrincipalId: string | undefined;
  PrincipalType: PrincipalType | undefined;
}
export interface ApplicationAssignmentForPrincipal {
  ApplicationArn?: string | undefined;
  PrincipalId?: string | undefined;
  PrincipalType?: PrincipalType | undefined;
}
export declare const AuthenticationMethodType: {
  readonly IAM: "IAM";
};
export type AuthenticationMethodType =
  (typeof AuthenticationMethodType)[keyof typeof AuthenticationMethodType];
export interface DeleteApplicationAuthenticationMethodRequest {
  ApplicationArn: string | undefined;
  AuthenticationMethodType: AuthenticationMethodType | undefined;
}
export interface GetApplicationAuthenticationMethodRequest {
  ApplicationArn: string | undefined;
  AuthenticationMethodType: AuthenticationMethodType | undefined;
}
export interface IamAuthenticationMethod {
  ActorPolicy: __DocumentType | undefined;
}
export type AuthenticationMethod =
  | AuthenticationMethod.IamMember
  | AuthenticationMethod.$UnknownMember;
export declare namespace AuthenticationMethod {
  interface IamMember {
    Iam: IamAuthenticationMethod;
    $unknown?: never;
  }
  interface $UnknownMember {
    Iam?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    Iam: (value: IamAuthenticationMethod) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: AuthenticationMethod, visitor: Visitor<T>) => T;
}
export interface GetApplicationAuthenticationMethodResponse {
  AuthenticationMethod?: AuthenticationMethod | undefined;
}
export interface ListApplicationAuthenticationMethodsRequest {
  ApplicationArn: string | undefined;
  NextToken?: string | undefined;
}
export interface AuthenticationMethodItem {
  AuthenticationMethodType?: AuthenticationMethodType | undefined;
  AuthenticationMethod?: AuthenticationMethod | undefined;
}
export interface ListApplicationAuthenticationMethodsResponse {
  AuthenticationMethods?: AuthenticationMethodItem[] | undefined;
  NextToken?: string | undefined;
}
export interface PutApplicationAuthenticationMethodRequest {
  ApplicationArn: string | undefined;
  AuthenticationMethodType: AuthenticationMethodType | undefined;
  AuthenticationMethod: AuthenticationMethod | undefined;
}
export declare const GrantType: {
  readonly AUTHORIZATION_CODE: "authorization_code";
  readonly JWT_BEARER: "urn:ietf:params:oauth:grant-type:jwt-bearer";
  readonly REFRESH_TOKEN: "refresh_token";
  readonly TOKEN_EXCHANGE: "urn:ietf:params:oauth:grant-type:token-exchange";
};
export type GrantType = (typeof GrantType)[keyof typeof GrantType];
export interface DeleteApplicationGrantRequest {
  ApplicationArn: string | undefined;
  GrantType: GrantType | undefined;
}
export interface GetApplicationGrantRequest {
  ApplicationArn: string | undefined;
  GrantType: GrantType | undefined;
}
export interface AuthorizationCodeGrant {
  RedirectUris?: string[] | undefined;
}
export interface AuthorizedTokenIssuer {
  TrustedTokenIssuerArn?: string | undefined;
  AuthorizedAudiences?: string[] | undefined;
}
export interface JwtBearerGrant {
  AuthorizedTokenIssuers?: AuthorizedTokenIssuer[] | undefined;
}
export interface RefreshTokenGrant {}
export interface TokenExchangeGrant {}
export type Grant =
  | Grant.AuthorizationCodeMember
  | Grant.JwtBearerMember
  | Grant.RefreshTokenMember
  | Grant.TokenExchangeMember
  | Grant.$UnknownMember;
export declare namespace Grant {
  interface AuthorizationCodeMember {
    AuthorizationCode: AuthorizationCodeGrant;
    JwtBearer?: never;
    RefreshToken?: never;
    TokenExchange?: never;
    $unknown?: never;
  }
  interface JwtBearerMember {
    AuthorizationCode?: never;
    JwtBearer: JwtBearerGrant;
    RefreshToken?: never;
    TokenExchange?: never;
    $unknown?: never;
  }
  interface RefreshTokenMember {
    AuthorizationCode?: never;
    JwtBearer?: never;
    RefreshToken: RefreshTokenGrant;
    TokenExchange?: never;
    $unknown?: never;
  }
  interface TokenExchangeMember {
    AuthorizationCode?: never;
    JwtBearer?: never;
    RefreshToken?: never;
    TokenExchange: TokenExchangeGrant;
    $unknown?: never;
  }
  interface $UnknownMember {
    AuthorizationCode?: never;
    JwtBearer?: never;
    RefreshToken?: never;
    TokenExchange?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    AuthorizationCode: (value: AuthorizationCodeGrant) => T;
    JwtBearer: (value: JwtBearerGrant) => T;
    RefreshToken: (value: RefreshTokenGrant) => T;
    TokenExchange: (value: TokenExchangeGrant) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(value: Grant, visitor: Visitor<T>) => T;
}
export interface GetApplicationGrantResponse {
  Grant: Grant | undefined;
}
export interface ListApplicationGrantsRequest {
  ApplicationArn: string | undefined;
  NextToken?: string | undefined;
}
export interface GrantItem {
  GrantType: GrantType | undefined;
  Grant: Grant | undefined;
}
export interface ListApplicationGrantsResponse {
  Grants: GrantItem[] | undefined;
  NextToken?: string | undefined;
}
export interface PutApplicationGrantRequest {
  ApplicationArn: string | undefined;
  GrantType: GrantType | undefined;
  Grant: Grant | undefined;
}
export interface DisplayData {
  DisplayName?: string | undefined;
  IconUrl?: string | undefined;
  Description?: string | undefined;
}
export declare const FederationProtocol: {
  readonly OAUTH: "OAUTH";
  readonly SAML: "SAML";
};
export type FederationProtocol =
  (typeof FederationProtocol)[keyof typeof FederationProtocol];
export interface ResourceServerScopeDetails {
  LongDescription?: string | undefined;
  DetailedTitle?: string | undefined;
}
export interface ResourceServerConfig {
  Scopes?: Record<string, ResourceServerScopeDetails> | undefined;
}
export interface ApplicationProvider {
  ApplicationProviderArn: string | undefined;
  FederationProtocol?: FederationProtocol | undefined;
  DisplayData?: DisplayData | undefined;
  ResourceServerConfig?: ResourceServerConfig | undefined;
}
export interface CustomerManagedPolicyReference {
  Name: string | undefined;
  Path?: string | undefined;
}
export interface AttachCustomerManagedPolicyReferenceToPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  CustomerManagedPolicyReference: CustomerManagedPolicyReference | undefined;
}
export interface AttachCustomerManagedPolicyReferenceToPermissionSetResponse {}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface AttachedManagedPolicy {
  Name?: string | undefined;
  Arn?: string | undefined;
}
export interface AttachManagedPolicyToPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  ManagedPolicyArn: string | undefined;
}
export interface AttachManagedPolicyToPermissionSetResponse {}
export interface CreateAccountAssignmentRequest {
  InstanceArn: string | undefined;
  TargetId: string | undefined;
  TargetType: TargetType | undefined;
  PermissionSetArn: string | undefined;
  PrincipalType: PrincipalType | undefined;
  PrincipalId: string | undefined;
}
export interface CreateAccountAssignmentResponse {
  AccountAssignmentCreationStatus?:
    | AccountAssignmentOperationStatus
    | undefined;
}
export interface Tag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface CreateApplicationRequest {
  InstanceArn: string | undefined;
  ApplicationProviderArn: string | undefined;
  Name: string | undefined;
  Description?: string | undefined;
  PortalOptions?: PortalOptions | undefined;
  Tags?: Tag[] | undefined;
  Status?: ApplicationStatus | undefined;
  ClientToken?: string | undefined;
}
export interface CreateApplicationResponse {
  ApplicationArn?: string | undefined;
}
export interface CreateApplicationAssignmentRequest {
  ApplicationArn: string | undefined;
  PrincipalId: string | undefined;
  PrincipalType: PrincipalType | undefined;
}
export interface CreateApplicationAssignmentResponse {}
export interface CreateInstanceRequest {
  Name?: string | undefined;
  ClientToken?: string | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateInstanceResponse {
  InstanceArn?: string | undefined;
}
export interface InstanceAccessControlAttributeConfiguration {
  AccessControlAttributes: AccessControlAttribute[] | undefined;
}
export interface CreateInstanceAccessControlAttributeConfigurationRequest {
  InstanceArn: string | undefined;
  InstanceAccessControlAttributeConfiguration:
    | InstanceAccessControlAttributeConfiguration
    | undefined;
}
export interface CreateInstanceAccessControlAttributeConfigurationResponse {}
export interface CreatePermissionSetRequest {
  Name: string | undefined;
  Description?: string | undefined;
  InstanceArn: string | undefined;
  SessionDuration?: string | undefined;
  RelayState?: string | undefined;
  Tags?: Tag[] | undefined;
}
export interface PermissionSet {
  Name?: string | undefined;
  PermissionSetArn?: string | undefined;
  Description?: string | undefined;
  CreatedDate?: Date | undefined;
  SessionDuration?: string | undefined;
  RelayState?: string | undefined;
}
export interface CreatePermissionSetResponse {
  PermissionSet?: PermissionSet | undefined;
}
export declare const JwksRetrievalOption: {
  readonly OPEN_ID_DISCOVERY: "OPEN_ID_DISCOVERY";
};
export type JwksRetrievalOption =
  (typeof JwksRetrievalOption)[keyof typeof JwksRetrievalOption];
export interface OidcJwtConfiguration {
  IssuerUrl: string | undefined;
  ClaimAttributePath: string | undefined;
  IdentityStoreAttributePath: string | undefined;
  JwksRetrievalOption: JwksRetrievalOption | undefined;
}
export type TrustedTokenIssuerConfiguration =
  | TrustedTokenIssuerConfiguration.OidcJwtConfigurationMember
  | TrustedTokenIssuerConfiguration.$UnknownMember;
export declare namespace TrustedTokenIssuerConfiguration {
  interface OidcJwtConfigurationMember {
    OidcJwtConfiguration: OidcJwtConfiguration;
    $unknown?: never;
  }
  interface $UnknownMember {
    OidcJwtConfiguration?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    OidcJwtConfiguration: (value: OidcJwtConfiguration) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(
    value: TrustedTokenIssuerConfiguration,
    visitor: Visitor<T>
  ) => T;
}
export declare const TrustedTokenIssuerType: {
  readonly OIDC_JWT: "OIDC_JWT";
};
export type TrustedTokenIssuerType =
  (typeof TrustedTokenIssuerType)[keyof typeof TrustedTokenIssuerType];
export interface CreateTrustedTokenIssuerRequest {
  InstanceArn: string | undefined;
  Name: string | undefined;
  TrustedTokenIssuerType: TrustedTokenIssuerType | undefined;
  TrustedTokenIssuerConfiguration: TrustedTokenIssuerConfiguration | undefined;
  ClientToken?: string | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateTrustedTokenIssuerResponse {
  TrustedTokenIssuerArn?: string | undefined;
}
export interface DeleteAccountAssignmentRequest {
  InstanceArn: string | undefined;
  TargetId: string | undefined;
  TargetType: TargetType | undefined;
  PermissionSetArn: string | undefined;
  PrincipalType: PrincipalType | undefined;
  PrincipalId: string | undefined;
}
export interface DeleteAccountAssignmentResponse {
  AccountAssignmentDeletionStatus?:
    | AccountAssignmentOperationStatus
    | undefined;
}
export interface DeleteApplicationRequest {
  ApplicationArn: string | undefined;
}
export interface DeleteApplicationResponse {}
export interface DeleteApplicationAssignmentRequest {
  ApplicationArn: string | undefined;
  PrincipalId: string | undefined;
  PrincipalType: PrincipalType | undefined;
}
export interface DeleteApplicationAssignmentResponse {}
export interface DeleteInlinePolicyFromPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
}
export interface DeleteInlinePolicyFromPermissionSetResponse {}
export interface DeleteInstanceRequest {
  InstanceArn: string | undefined;
}
export interface DeleteInstanceResponse {}
export interface DeleteInstanceAccessControlAttributeConfigurationRequest {
  InstanceArn: string | undefined;
}
export interface DeleteInstanceAccessControlAttributeConfigurationResponse {}
export interface DeletePermissionsBoundaryFromPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
}
export interface DeletePermissionsBoundaryFromPermissionSetResponse {}
export interface DeletePermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
}
export interface DeletePermissionSetResponse {}
export interface DeleteTrustedTokenIssuerRequest {
  TrustedTokenIssuerArn: string | undefined;
}
export interface DeleteTrustedTokenIssuerResponse {}
export interface DescribeAccountAssignmentCreationStatusRequest {
  InstanceArn: string | undefined;
  AccountAssignmentCreationRequestId: string | undefined;
}
export interface DescribeAccountAssignmentCreationStatusResponse {
  AccountAssignmentCreationStatus?:
    | AccountAssignmentOperationStatus
    | undefined;
}
export interface DescribeAccountAssignmentDeletionStatusRequest {
  InstanceArn: string | undefined;
  AccountAssignmentDeletionRequestId: string | undefined;
}
export interface DescribeAccountAssignmentDeletionStatusResponse {
  AccountAssignmentDeletionStatus?:
    | AccountAssignmentOperationStatus
    | undefined;
}
export interface DescribeApplicationRequest {
  ApplicationArn: string | undefined;
}
export interface DescribeApplicationResponse {
  ApplicationArn?: string | undefined;
  ApplicationProviderArn?: string | undefined;
  Name?: string | undefined;
  ApplicationAccount?: string | undefined;
  InstanceArn?: string | undefined;
  Status?: ApplicationStatus | undefined;
  PortalOptions?: PortalOptions | undefined;
  Description?: string | undefined;
  CreatedDate?: Date | undefined;
}
export interface DescribeApplicationAssignmentRequest {
  ApplicationArn: string | undefined;
  PrincipalId: string | undefined;
  PrincipalType: PrincipalType | undefined;
}
export interface DescribeApplicationAssignmentResponse {
  PrincipalType?: PrincipalType | undefined;
  PrincipalId?: string | undefined;
  ApplicationArn?: string | undefined;
}
export interface DescribeApplicationProviderRequest {
  ApplicationProviderArn: string | undefined;
}
export interface DescribeApplicationProviderResponse {
  ApplicationProviderArn: string | undefined;
  FederationProtocol?: FederationProtocol | undefined;
  DisplayData?: DisplayData | undefined;
  ResourceServerConfig?: ResourceServerConfig | undefined;
}
export interface DescribeInstanceRequest {
  InstanceArn: string | undefined;
}
export declare const InstanceStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS";
  readonly DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS";
};
export type InstanceStatus =
  (typeof InstanceStatus)[keyof typeof InstanceStatus];
export interface DescribeInstanceResponse {
  InstanceArn?: string | undefined;
  IdentityStoreId?: string | undefined;
  OwnerAccountId?: string | undefined;
  Name?: string | undefined;
  CreatedDate?: Date | undefined;
  Status?: InstanceStatus | undefined;
}
export interface DescribeInstanceAccessControlAttributeConfigurationRequest {
  InstanceArn: string | undefined;
}
export declare const InstanceAccessControlAttributeConfigurationStatus: {
  readonly CREATION_FAILED: "CREATION_FAILED";
  readonly CREATION_IN_PROGRESS: "CREATION_IN_PROGRESS";
  readonly ENABLED: "ENABLED";
};
export type InstanceAccessControlAttributeConfigurationStatus =
  (typeof InstanceAccessControlAttributeConfigurationStatus)[keyof typeof InstanceAccessControlAttributeConfigurationStatus];
export interface DescribeInstanceAccessControlAttributeConfigurationResponse {
  Status?: InstanceAccessControlAttributeConfigurationStatus | undefined;
  StatusReason?: string | undefined;
  InstanceAccessControlAttributeConfiguration?:
    | InstanceAccessControlAttributeConfiguration
    | undefined;
}
export interface DescribePermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
}
export interface DescribePermissionSetResponse {
  PermissionSet?: PermissionSet | undefined;
}
export interface DescribePermissionSetProvisioningStatusRequest {
  InstanceArn: string | undefined;
  ProvisionPermissionSetRequestId: string | undefined;
}
export interface PermissionSetProvisioningStatus {
  Status?: StatusValues | undefined;
  RequestId?: string | undefined;
  AccountId?: string | undefined;
  PermissionSetArn?: string | undefined;
  FailureReason?: string | undefined;
  CreatedDate?: Date | undefined;
}
export interface DescribePermissionSetProvisioningStatusResponse {
  PermissionSetProvisioningStatus?: PermissionSetProvisioningStatus | undefined;
}
export interface DescribeTrustedTokenIssuerRequest {
  TrustedTokenIssuerArn: string | undefined;
}
export interface DescribeTrustedTokenIssuerResponse {
  TrustedTokenIssuerArn?: string | undefined;
  Name?: string | undefined;
  TrustedTokenIssuerType?: TrustedTokenIssuerType | undefined;
  TrustedTokenIssuerConfiguration?: TrustedTokenIssuerConfiguration | undefined;
}
export interface DetachCustomerManagedPolicyReferenceFromPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  CustomerManagedPolicyReference: CustomerManagedPolicyReference | undefined;
}
export interface DetachCustomerManagedPolicyReferenceFromPermissionSetResponse {}
export interface DetachManagedPolicyFromPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  ManagedPolicyArn: string | undefined;
}
export interface DetachManagedPolicyFromPermissionSetResponse {}
export interface GetApplicationAssignmentConfigurationRequest {
  ApplicationArn: string | undefined;
}
export interface GetApplicationAssignmentConfigurationResponse {
  AssignmentRequired: boolean | undefined;
}
export interface GetInlinePolicyForPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
}
export interface GetInlinePolicyForPermissionSetResponse {
  InlinePolicy?: string | undefined;
}
export interface GetPermissionsBoundaryForPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
}
export interface PermissionsBoundary {
  CustomerManagedPolicyReference?: CustomerManagedPolicyReference | undefined;
  ManagedPolicyArn?: string | undefined;
}
export interface GetPermissionsBoundaryForPermissionSetResponse {
  PermissionsBoundary?: PermissionsBoundary | undefined;
}
export interface InstanceMetadata {
  InstanceArn?: string | undefined;
  IdentityStoreId?: string | undefined;
  OwnerAccountId?: string | undefined;
  Name?: string | undefined;
  CreatedDate?: Date | undefined;
  Status?: InstanceStatus | undefined;
}
export interface OperationStatusFilter {
  Status?: StatusValues | undefined;
}
export interface ListAccountAssignmentCreationStatusRequest {
  InstanceArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  Filter?: OperationStatusFilter | undefined;
}
export interface ListAccountAssignmentCreationStatusResponse {
  AccountAssignmentsCreationStatus?:
    | AccountAssignmentOperationStatusMetadata[]
    | undefined;
  NextToken?: string | undefined;
}
export interface ListAccountAssignmentDeletionStatusRequest {
  InstanceArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  Filter?: OperationStatusFilter | undefined;
}
export interface ListAccountAssignmentDeletionStatusResponse {
  AccountAssignmentsDeletionStatus?:
    | AccountAssignmentOperationStatusMetadata[]
    | undefined;
  NextToken?: string | undefined;
}
export interface ListAccountAssignmentsRequest {
  InstanceArn: string | undefined;
  AccountId: string | undefined;
  PermissionSetArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAccountAssignmentsResponse {
  AccountAssignments?: AccountAssignment[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAccountAssignmentsFilter {
  AccountId?: string | undefined;
}
export interface ListAccountAssignmentsForPrincipalRequest {
  InstanceArn: string | undefined;
  PrincipalId: string | undefined;
  PrincipalType: PrincipalType | undefined;
  Filter?: ListAccountAssignmentsFilter | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListAccountAssignmentsForPrincipalResponse {
  AccountAssignments?: AccountAssignmentForPrincipal[] | undefined;
  NextToken?: string | undefined;
}
export declare const ProvisioningStatus: {
  readonly LATEST_PERMISSION_SET_NOT_PROVISIONED: "LATEST_PERMISSION_SET_NOT_PROVISIONED";
  readonly LATEST_PERMISSION_SET_PROVISIONED: "LATEST_PERMISSION_SET_PROVISIONED";
};
export type ProvisioningStatus =
  (typeof ProvisioningStatus)[keyof typeof ProvisioningStatus];
export interface ListAccountsForProvisionedPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  ProvisioningStatus?: ProvisioningStatus | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAccountsForProvisionedPermissionSetResponse {
  AccountIds?: string[] | undefined;
  NextToken?: string | undefined;
}
export interface ListApplicationAssignmentsRequest {
  ApplicationArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListApplicationAssignmentsResponse {
  ApplicationAssignments?: ApplicationAssignment[] | undefined;
  NextToken?: string | undefined;
}
export interface ListApplicationAssignmentsFilter {
  ApplicationArn?: string | undefined;
}
export interface ListApplicationAssignmentsForPrincipalRequest {
  InstanceArn: string | undefined;
  PrincipalId: string | undefined;
  PrincipalType: PrincipalType | undefined;
  Filter?: ListApplicationAssignmentsFilter | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListApplicationAssignmentsForPrincipalResponse {
  ApplicationAssignments?: ApplicationAssignmentForPrincipal[] | undefined;
  NextToken?: string | undefined;
}
export interface ListApplicationProvidersRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListApplicationProvidersResponse {
  ApplicationProviders?: ApplicationProvider[] | undefined;
  NextToken?: string | undefined;
}
export interface ListApplicationsFilter {
  ApplicationAccount?: string | undefined;
  ApplicationProvider?: string | undefined;
}
export interface ListApplicationsRequest {
  InstanceArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  Filter?: ListApplicationsFilter | undefined;
}
export interface ListApplicationsResponse {
  Applications?: Application[] | undefined;
  NextToken?: string | undefined;
}
export interface ListCustomerManagedPolicyReferencesInPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListCustomerManagedPolicyReferencesInPermissionSetResponse {
  CustomerManagedPolicyReferences?:
    | CustomerManagedPolicyReference[]
    | undefined;
  NextToken?: string | undefined;
}
export interface ListInstancesRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListInstancesResponse {
  Instances?: InstanceMetadata[] | undefined;
  NextToken?: string | undefined;
}
export interface ListManagedPoliciesInPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListManagedPoliciesInPermissionSetResponse {
  AttachedManagedPolicies?: AttachedManagedPolicy[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPermissionSetProvisioningStatusRequest {
  InstanceArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  Filter?: OperationStatusFilter | undefined;
}
export interface PermissionSetProvisioningStatusMetadata {
  Status?: StatusValues | undefined;
  RequestId?: string | undefined;
  CreatedDate?: Date | undefined;
}
export interface ListPermissionSetProvisioningStatusResponse {
  PermissionSetsProvisioningStatus?:
    | PermissionSetProvisioningStatusMetadata[]
    | undefined;
  NextToken?: string | undefined;
}
export interface ListPermissionSetsRequest {
  InstanceArn: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListPermissionSetsResponse {
  PermissionSets?: string[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPermissionSetsProvisionedToAccountRequest {
  InstanceArn: string | undefined;
  AccountId: string | undefined;
  ProvisioningStatus?: ProvisioningStatus | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListPermissionSetsProvisionedToAccountResponse {
  NextToken?: string | undefined;
  PermissionSets?: string[] | undefined;
}
export interface ListTagsForResourceRequest {
  InstanceArn?: string | undefined;
  ResourceArn: string | undefined;
  NextToken?: string | undefined;
}
export interface ListTagsForResourceResponse {
  Tags?: Tag[] | undefined;
  NextToken?: string | undefined;
}
export interface ListTrustedTokenIssuersRequest {
  InstanceArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface TrustedTokenIssuerMetadata {
  TrustedTokenIssuerArn?: string | undefined;
  Name?: string | undefined;
  TrustedTokenIssuerType?: TrustedTokenIssuerType | undefined;
}
export interface ListTrustedTokenIssuersResponse {
  TrustedTokenIssuers?: TrustedTokenIssuerMetadata[] | undefined;
  NextToken?: string | undefined;
}
export interface OidcJwtUpdateConfiguration {
  ClaimAttributePath?: string | undefined;
  IdentityStoreAttributePath?: string | undefined;
  JwksRetrievalOption?: JwksRetrievalOption | undefined;
}
export declare const ProvisionTargetType: {
  readonly ALL_PROVISIONED_ACCOUNTS: "ALL_PROVISIONED_ACCOUNTS";
  readonly AWS_ACCOUNT: "AWS_ACCOUNT";
};
export type ProvisionTargetType =
  (typeof ProvisionTargetType)[keyof typeof ProvisionTargetType];
export interface ProvisionPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  TargetId?: string | undefined;
  TargetType: ProvisionTargetType | undefined;
}
export interface ProvisionPermissionSetResponse {
  PermissionSetProvisioningStatus?: PermissionSetProvisioningStatus | undefined;
}
export interface PutApplicationAssignmentConfigurationRequest {
  ApplicationArn: string | undefined;
  AssignmentRequired: boolean | undefined;
}
export interface PutApplicationAssignmentConfigurationResponse {}
export interface PutInlinePolicyToPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  InlinePolicy: string | undefined;
}
export interface PutInlinePolicyToPermissionSetResponse {}
export interface PutPermissionsBoundaryToPermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  PermissionsBoundary: PermissionsBoundary | undefined;
}
export interface PutPermissionsBoundaryToPermissionSetResponse {}
export interface TagResourceRequest {
  InstanceArn?: string | undefined;
  ResourceArn: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  InstanceArn?: string | undefined;
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateApplicationPortalOptions {
  SignInOptions?: SignInOptions | undefined;
}
export interface UpdateApplicationRequest {
  ApplicationArn: string | undefined;
  Name?: string | undefined;
  Description?: string | undefined;
  Status?: ApplicationStatus | undefined;
  PortalOptions?: UpdateApplicationPortalOptions | undefined;
}
export interface UpdateApplicationResponse {}
export interface UpdateInstanceRequest {
  Name: string | undefined;
  InstanceArn: string | undefined;
}
export interface UpdateInstanceResponse {}
export interface UpdateInstanceAccessControlAttributeConfigurationRequest {
  InstanceArn: string | undefined;
  InstanceAccessControlAttributeConfiguration:
    | InstanceAccessControlAttributeConfiguration
    | undefined;
}
export interface UpdateInstanceAccessControlAttributeConfigurationResponse {}
export interface UpdatePermissionSetRequest {
  InstanceArn: string | undefined;
  PermissionSetArn: string | undefined;
  Description?: string | undefined;
  SessionDuration?: string | undefined;
  RelayState?: string | undefined;
}
export interface UpdatePermissionSetResponse {}
export type TrustedTokenIssuerUpdateConfiguration =
  | TrustedTokenIssuerUpdateConfiguration.OidcJwtConfigurationMember
  | TrustedTokenIssuerUpdateConfiguration.$UnknownMember;
export declare namespace TrustedTokenIssuerUpdateConfiguration {
  interface OidcJwtConfigurationMember {
    OidcJwtConfiguration: OidcJwtUpdateConfiguration;
    $unknown?: never;
  }
  interface $UnknownMember {
    OidcJwtConfiguration?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    OidcJwtConfiguration: (value: OidcJwtUpdateConfiguration) => T;
    _: (name: string, value: any) => T;
  }
  const visit: <T>(
    value: TrustedTokenIssuerUpdateConfiguration,
    visitor: Visitor<T>
  ) => T;
}
export interface UpdateTrustedTokenIssuerRequest {
  TrustedTokenIssuerArn: string | undefined;
  Name?: string | undefined;
  TrustedTokenIssuerConfiguration?:
    | TrustedTokenIssuerUpdateConfiguration
    | undefined;
}
export interface UpdateTrustedTokenIssuerResponse {}
